#!perl -T

use Test::More;
eval "use Test::Pod 1.14";
plan skip_all => 'Test::Pod only run for author tests' unless $ENV{AUTHOR_TEST};
plan skip_all => "Test::Pod 1.14 required for testing POD" if $@;
all_pod_files_ok();
